﻿using System.Linq;
using System.Net.Mail;
using System.Web.Mvc;
using CommonHotelApplication.Models;
using Model;

namespace CommonHotelApplication.Controllers
{
    [RouteArea("hromadna-rozesilka-emailu")]
    public class MailingController : BaseController
    {
        private readonly HotelModel _hotelModel;

        public MailingController()
        {
            _hotelModel = new HotelModel();
        }

        [HttpGet]
        [Route("")]
        public ActionResult Index()
        {
            return View(new MailingVM
            {
                Hotels = _hotelModel.Hotels.ToList()
            });
        }

        [HttpPost]
        [Route("")]
        public ActionResult Index(MailingVM vm)
        {
            if (string.IsNullOrEmpty(vm.Subject))
            {
                ModelState.AddModelError("Subject","Předmět zprávy nesmí být prázdný.");
            }
            if (string.IsNullOrEmpty(vm.Sender))
            {
                ModelState.AddModelError("Sender", "Odesílatel zprávy nesmí být prázdný.");
            }
            if (string.IsNullOrEmpty(vm.Body?.ToHtmlString()))
            {
                ModelState.AddModelError("Body", "Tělo zprávy nesmí být prázdné.");
            }
            if (vm.SelectedHotelEmails == null || !vm.SelectedHotelEmails.Any())
            {
                ModelState.AddModelError("SelectedHotelIds", "Vyberte alespoň jeden hotel.");
            }
            if (!ModelState.IsValid)
            {
                vm.Hotels = _hotelModel.Hotels.ToList();
                return View(vm);
            }
            foreach (var hotelEmail in vm.SelectedHotelEmails)
            {
                var mail = new MailMessage("info@pc-zone.cz", hotelEmail);
                var client = new SmtpClient
                {
                    Port = 25,
                    DeliveryMethod = SmtpDeliveryMethod.Network,
                    UseDefaultCredentials = true
                };
                mail.Subject = vm.Subject;
                mail.Body = vm.Body.ToHtmlString();
                mail.IsBodyHtml = true;
                client.Send(mail);
            }
            
            return RedirectToAction("Index", "Home");
        }
    }
}